(self.webpackChunkJLTomorrowNight=self.webpackChunkJLTomorrowNight||[]).push([[568],{568:(o,r,e)=>{"use strict";e.r(r),e.d(r,{default:()=>i});var a=e(120),t=e(410);const i={id:"JLTomorrowNight:plugin",requires:[a.IThemeManager,t.ITranslator],activate:(o,r,e)=>{const a=e.load("jupyterlab");r.register({name:"JLTomorrowNight",displayName:a.__("JLTomorrowNight"),isLight:!1,themeScrollbars:!0,load:()=>r.loadCSS("JLTomorrowNight/index.css"),unload:()=>Promise.resolve(void 0)})},autoStart:!0}}}]);